@@ -6,7 +6,7 @@ from pydantic_core import __version__ as __pydantic_core_version__
 
 __all__ = 'VERSION', 'version_info'
 
-VERSION = '2.11.0'
+VERSION = '2.11.6'
 """The version of Pydantic."""
 
 
@@ -20,8 +20,7 @@ def version_short() -> str:
 
 def version_info() -> str:
     """Return complete version information for Pydantic and its dependencies."""
-    import importlib.metadata as importlib_metadata
-    import os
+    import importlib.metadata
     import platform
     import sys
     from pathlib import Path
@@ -42,12 +41,12 @@ def version_info() -> str:
     }
     related_packages = []
 
-    for dist in importlib_metadata.distributions():
+    for dist in importlib.metadata.distributions():
         name = dist.metadata['Name']
         if name in package_names:
             related_packages.append(f'{name}-{dist.version}')
 
-    pydantic_dir = os.path.abspath(os.path.dirname(os.path.dirname(__file__)))
+    pydantic_dir = Path(__file__).parents[1].resolve()
     most_recent_commit = (
         git.git_revision(pydantic_dir) if git.is_git_repo(pydantic_dir) and git.have_git() else 'unknown'
     )
@@ -56,7 +55,6 @@ def version_info() -> str:
         'pydantic version': VERSION,
         'pydantic-core version': pdc.__version__,
         'pydantic-core build': getattr(pdc, 'build_info', None) or pdc.build_profile,
-        'install path': Path(__file__).resolve().parent,
         'python version': sys.version,
         'platform': platform.platform(),
         'related packages': ' '.join(related_packages),
@@ -68,7 +66,7 @@ def version_info() -> str:
 def check_pydantic_core_version() -> bool:
     """Check that the installed `pydantic-core` dependency is compatible."""
     # Keep this in sync with the version constraint in the `pyproject.toml` dependencies:
-    return __pydantic_core_version__ == '2.33.0'
+    return __pydantic_core_version__ == '2.33.2'
 
 
 def parse_mypy_version(version: str) -> tuple[int, int, int]:
